==> apache-ranger-1.2.0.tar.gz: apache-ranger-1.2.0/security-admin/src/test/java/org/apache/ranger/service/TestRangerTransactionService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.ranger.service;

import java.util.concurrent.ScheduledExecutorService;

import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.MethodSorters;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

@RunWith(MockitoJUnitRunner.class)
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class TestRangerTransactionService {

	@InjectMocks
	RangerTransactionService rangerTransactionService;

	@Mock
	ScheduledExecutorService scheduler;

	@Mock
	Runnable task;

	@Test
	public void test1Init() {
		rangerTransactionService.init();

	}

	@Test
	public void test2Destroy() {
		rangerTransactionService.destroy();

	}

	@Test
	public void test3ExecuteAfterTransactionComplete() {
		rangerTransactionService.executeAfterTransactionComplete(task);

	}
}

==> apache-ranger-2.7.0.tar.gz: apache-ranger-2.7.0/security-admin/src/test/java/org/apache/ranger/service/TestRangerTransactionService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.ranger.service;

import java.util.concurrent.ScheduledExecutorService;

import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.MethodSorters;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

@RunWith(MockitoJUnitRunner.class)
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class TestRangerTransactionService {

	@InjectMocks
	RangerTransactionService rangerTransactionService;

	@Mock
	ScheduledExecutorService scheduler;

	@Mock
	Runnable task;

	@Test
	public void test1Init() {
		rangerTransactionService.init();

	}

	@Test
	public void test2Destroy() {
		rangerTransactionService.destroy();

	}

	@Test
	public void test3ExecuteAfterTransactionComplete() {
		rangerTransactionService.scheduleToExecuteInOwnTransaction(task, 1000L);

	}
}
